Index: tests/phpunit/testcases/groups/class-bp-groups-member.php
===================================================================
--- tests/phpunit/testcases/groups/class-bp-groups-member.php
+++ tests/phpunit/testcases/groups/class-bp-groups-member.php
@@ -1150,6 +1150,42 @@
 	}
 
 	/**
+	 * @group groups_get_invites_for_group
+	 * @group group_send_invites
+	 * @group group_invitations
+	 * @group group_membership
+	 */
+	public function test_groups_get_invites_for_group_with_sent_parameter() {
+		$u1 = $this->factory->user->create();
+		$u2 = $this->factory->user->create();
+		$g1 = $this->factory->group->create( array( 'creator_id' => $u1 ) );
+
+		// Create draft invitation
+		groups_invite_user( array(
+			'user_id'       => $u2,
+			'group_id'      => $g1,
+			'inviter_id'    => $u1,
+			'date_modified' => bp_core_current_time(),
+			'is_confirmed'  => 0
+		) );
+
+		// Send the invitation; this will set the 'invite_sent' value to 1.
+		groups_send_invites( $u1, $g1 );
+
+		// Default groups_get_invites_for_group() call
+		$i = groups_get_invites_for_group( $u1, $g1 );
+		$this->assertEqualSets( array( $u2 ), $i );
+
+		// Fetch users whose invites have been sent out; should be the same as above.
+		$i = groups_get_invites_for_group( $u1, $g1 );
+		$this->assertEqualSets( array( $u2 ), $i );
+
+		// Fetch users whose invites haven't been sent yet.
+		$i = groups_get_invites_for_group( $u1, $g1, 0 );
+		$this->assertEmpty( $i );
+	}
+
+	/**
 	 * @group groups_send_membership_request
 	 * @group group_membership_requests
 	 * @group group_membership

Index: src/bp-groups/bp-groups-functions.php
===================================================================
--- src/bp-groups/bp-groups-functions.php
+++ src/bp-groups/bp-groups-functions.php
@@ -1508,17 +1508,28 @@
  * Send all pending invites by a single user to a specific group.
  *
  * @since 1.0.0
+ * @since 2.8.0 Added $omit_sent as a parameter.
  *
- * @param int $user_id  ID of the inviting user.
- * @param int $group_id ID of the group.
+ * @param int  $user_id   ID of the inviting user.
+ * @param int  $group_id  ID of the group.
+ * @param bool $omit_sent If true, we will not send invites to those we have already sent
+ *                        an invite to. If false, we will send an invite regardless of sent
+ *                        status.
  */
-function groups_send_invites( $user_id, $group_id ) {
+function groups_send_invites( $user_id, $group_id, $omit_sent = false ) {
 
-	if ( empty( $user_id ) )
+	if ( empty( $user_id ) ) {
 		$user_id = bp_loggedin_user_id();
+	}
+
+	if ( true === $omit_sent ) {
+		$sent = 0;
+	} else {
+		$sent = null;
+	}
 
 	// Send friend invites.
-	$invited_users = groups_get_invites_for_group( $user_id, $group_id );
+	$invited_users = groups_get_invites_for_group( $user_id, $group_id, $sent );
 	$group = groups_get_group( $group_id );
 
 	for ( $i = 0, $count = count( $invited_users ); $i < $count; ++$i ) {
@@ -1548,14 +1559,19 @@
  * Get IDs of users with outstanding invites to a given group from a specified user.
  *
  * @since 1.0.0
- *
- * @param int $user_id  ID of the inviting user.
- * @param int $group_id ID of the group.
- * @return array $value IDs of users who have been invited to the group by the
- *                      user but have not yet accepted.
- */
-function groups_get_invites_for_group( $user_id, $group_id ) {
-	return BP_Groups_Group::get_invites( $user_id, $group_id );
+ * @since 2.8.0 Added $sent as a parameter.
+ *
+ * @param  int      $user_id  ID of the inviting user.
+ * @param  int      $group_id ID of the group.
+ * @param  int|null $sent     Query for a specific invite sent status. If 0, this will query for users
+ *                            that haven't had an invite sent to them yet. If 1, this will query for
+ *                            users that have had an invite sent to them. If null, no invite status will
+ *                            queried. Default: null.
+ * @return array    IDs of users who have been invited to the group by the user but have not
+ *                  yet accepted.
+ */
+function groups_get_invites_for_group( $user_id, $group_id, $sent = null ) {
+	return BP_Groups_Group::get_invites( $user_id, $group_id, $sent );
 }
 
 /**
Index: src/bp-groups/classes/class-bp-groups-group.php
===================================================================
--- src/bp-groups/classes/class-bp-groups-group.php
+++ src/bp-groups/classes/class-bp-groups-group.php
@@ -648,18 +648,29 @@
 	 * Get IDs of users with outstanding invites to a given group from a specified user.
 	 *
 	 * @since 1.6.0
 	 *
 	 * @param int $user_id ID of the inviting user.
 	 * @param int $group_id ID of the group.
 	 * @return array IDs of users who have been invited to the group by the
 	 *               user but have not yet accepted.
 	 */
-	public static function get_invites( $user_id, $group_id ) {
+	public static function get_invites( $user_id, $group_id, $sent = null ) {
 		global $wpdb;
 
-		$bp = buddypress();
+		$bp  = buddypress();
+		$sql = $wpdb->prepare( "SELECT user_id FROM {$bp->groups->table_name_members} WHERE group_id = %d and is_confirmed = 0 AND inviter_id = %d", $group_id, $user_id );
+
+		// Query for a specific invite sent status.
+		if ( ! is_null( $sent ) ) {
+			$sql .= $wpdb->prepare( ' AND invite_sent = %d', $sent );
+		}
 
-		return $wpdb->get_col( $wpdb->prepare( "SELECT user_id FROM {$bp->groups->table_name_members} WHERE group_id = %d and is_confirmed = 0 AND inviter_id = %d", $group_id, $user_id ) );
+		return $wpdb->get_col( $sql );
 	}
 
 	/**
@@ -648,18 +648,29 @@
 	 *
 	 * @since 1.6.0
-	 *
-	 * @param int $user_id ID of the inviting user.
-	 * @param int $group_id ID of the group.
-	 * @return array IDs of users who have been invited to the group by the
-	 *               user but have not yet accepted.
+	 * @since 2.8.0 Added $sent as a parameter.
+	 *
+	 * @param  int      $user_id  ID of the inviting user.
+	 * @param  int      $group_id ID of the group.
+	 * @param  int|null $sent     Query for a specific invite sent status. If 0, this will query for users
+         *                            that haven't had an invite sent to them yet. If 1, this will query for
+         *                            users that have had an invite sent to them. If null, no invite status will
+         *                            queried. Default: null.
+	 * @return array    IDs of users who have been invited to the group by the user but have not
+	 *                  yet accepted.
 	 */